==> office-ui-fabric-vue-7.0.17.tgz: package/lib/tmp/components/Persona/PersonaPresence/PersonaPresence.styles.js <==
import { getGlobalClassNames, HighContrastSelector } from '@uifabric/styling';
import { sizeBoolean, presenceBoolean, personaPresenceSize } from '../PersonaConsts.js';

const GlobalClassNames = {
  presence: 'ms-Persona-presence',
  presenceIcon: 'ms-Persona-presenceIcon'
};
const getStyles = props => {
  const {
    theme
  } = props;
  const {
    semanticColors,
    fonts
  } = theme;
  const classNames = getGlobalClassNames(GlobalClassNames, theme);
  const size = sizeBoolean(props.size);
  const presence = presenceBoolean(props.presence); // Presence colors

  const presenceColorAvailable = '#6BB700';
  const presenceColorAway = '#FFAA44';
  const presenceColorBusy = '#C43148';
  const presenceColorDnd = '#C50F1F';
  const presenceColorOffline = '#8A8886';
  const presenceColorOof = '#B4009E';
  const isOpenCirclePresence = presence.isOffline || props.isOutOfOffice && (presence.isAvailable || presence.isBusy || presence.isAway || presence.isDoNotDisturb);
  const borderSizeForSmallPersonas = '1px';
  const borderSizeForLargePersonas = '2px';
  const borderSize = size.isSize72 || size.isSize100 ? borderSizeForLargePersonas : borderSizeForSmallPersonas;
  return {
    presence: [classNames.presence, {
      position: 'absolute',
      height: personaPresenceSize.size12,
      width: personaPresenceSize.size12,
      borderRadius: '50%',
      top: 'auto',
      right: '-2px',
      bottom: '-2px',
      border: `2px solid ${semanticColors.bodyBackground}`,
      textAlign: 'center',
      boxSizing: 'content-box',
      backgroundClip: 'content-box',
      MsHighContrastAdjust: 'none',
      selectors: {
        [HighContrastSelector]: {
          borderColor: 'Window',
          backgroundColor: 'WindowText'
        }
      }
    }, (size.isSize8 || size.isSize10) && {
      right: 'auto',
      top: '7px',
      left: 0,
      border: 0,
      selectors: {
        [HighContrastSelector]: {
          top: '9px',
          border: '1px solid WindowText'
        }
      }
    }, (size.isSize8 || size.isSize10 || size.isSize24 || size.isSize28 || size.isSize32) && makeSizeStyle(personaPresenceSize.size8), (size.isSize40 || size.isSize48) && makeSizeStyle(personaPresenceSize.size12), size.isSize16 && {
      height: personaPresenceSize.size6,
      width: personaPresenceSize.size6,
      borderWidth: '1.5px'
    }, size.isSize56 && makeSizeStyle(personaPresenceSize.size16), size.isSize72 && makeSizeStyle(personaPresenceSize.size20), size.isSize100 && makeSizeStyle(personaPresenceSize.size28), size.isSize120 && makeSizeStyle(personaPresenceSize.size32), presence.isAvailable && {
      backgroundColor: presenceColorAvailable,
      selectors: {
        [HighContrastSelector]: backgroundColor('Highlight')
      }
    }, presence.isAway && backgroundColor(presenceColorAway), presence.isBlocked && [{
      selectors: {
        // Only show :after at larger sizes
        ':after': size.isSize40 || size.isSize48 || size.isSize72 || size.isSize100 ? {
          content: '""',
          width: '100%',
          height: borderSize,
          backgroundColor: presenceColorBusy,
          transform: 'translateY(-50%) rotate(-45deg)',
          position: 'absolute',
          top: '50%',
          left: 0
        } : undefined,
        [HighContrastSelector]: {
          selectors: {
            ':after': {
              width: `calc(100% - 4px)`,
              left: '2px',
              backgroundColor: 'Window'
            }
          }
        }
      }
    }], presence.isBusy && backgroundColor(presenceColorBusy), presence.isDoNotDisturb && backgroundColor(presenceColorDnd), presence.isOffline && backgroundColor(presenceColorOffline), (isOpenCirclePresence || presence.isBlocked) && [{
      backgroundColor: semanticColors.bodyBackground,
      selectors: {
        ':before': {
          content: '""',
          width: '100%',
          height: '100%',
          position: 'absolute',
          top: 0,
          left: 0,
          border: `${borderSize} solid ${presenceColorBusy}`,
          borderRadius: '50%',
          boxSizing: 'border-box'
        },
        [HighContrastSelector]: {
          backgroundColor: 'WindowText',
          selectors: {
            ':before': {
              width: `calc(100% - 2px)`,
              height: `calc(100% - 2px)`,
              top: '1px',
              left: '1px',
              borderColor: 'Window'
            }
          }
        }
      }
    }], isOpenCirclePresence && presence.isAvailable && makeBeforeBorderStyle(borderSize, presenceColorAvailable), isOpenCirclePresence && presence.isBusy && makeBeforeBorderStyle(borderSize, presenceColorBusy), isOpenCirclePresence && presence.isAway && makeBeforeBorderStyle(borderSize, presenceColorOof), isOpenCirclePresence && presence.isDoNotDisturb && makeBeforeBorderStyle(borderSize, presenceColorDnd), isOpenCirclePresence && presence.isOffline && makeBeforeBorderStyle(borderSize, presenceColorOffline), isOpenCirclePresence && presence.isOffline && props.isOutOfOffice && makeBeforeBorderStyle(borderSize, presenceColorOof)],
    presenceIcon: [classNames.presenceIcon, {
      color: semanticColors.bodyBackground,
      fontSize: '6px',
      lineHeight: personaPresenceSize.size12,
      verticalAlign: 'top',
      selectors: {
        [HighContrastSelector]: {
          color: 'Window'
        }
      }
    }, size.isSize56 && {
      fontSize: '8px',
      lineHeight: personaPresenceSize.size16
    }, size.isSize72 && {
      fontSize: fonts.small.fontSize,
      lineHeight: personaPresenceSize.size20
    }, size.isSize100 && {
      fontSize: fonts.medium.fontSize,
      lineHeight: personaPresenceSize.size28
    }, size.isSize120 && {
      fontSize: fonts.medium.fontSize,
      lineHeight: personaPresenceSize.size32
    }, presence.isAway && {
      position: 'relative',
      left: isOpenCirclePresence ? undefined : '1px'
    }, isOpenCirclePresence && presence.isAvailable && makeOpenCircleIconStyle(presenceColorAvailable), isOpenCirclePresence && presence.isBusy && makeOpenCircleIconStyle(presenceColorBusy), isOpenCirclePresence && presence.isAway && makeOpenCircleIconStyle(presenceColorOof), isOpenCirclePresence && presence.isDoNotDisturb && makeOpenCircleIconStyle(presenceColorDnd), isOpenCirclePresence && presence.isOffline && makeOpenCircleIconStyle(presenceColorOffline), isOpenCirclePresence && presence.isOffline && props.isOutOfOffice && makeOpenCircleIconStyle(presenceColorOof)]
  };
};

function makeOpenCircleIconStyle(color) {
  return {
    color,
    borderColor: color
  };
}

function makeBeforeBorderStyle(borderSize, color) {
  return {
    selectors: {
      ':before': {
        border: `${borderSize} solid ${color}`
      }
    }
  };
}

function makeSizeStyle(size) {
  return {
    height: size,
    width: size
  };
}

function backgroundColor(color) {
  return {
    backgroundColor: color
  };
}

export { getStyles };

==> office-ui-fabric-vue-7.0.24.tgz: package/lib/tmp/components/Persona/PersonaPresence/PersonaPresence.styles.js <==
import '../../../../node_modules/core-js/modules/es.array.concat.js';
import { getGlobalClassNames, HighContrastSelector } from '@uifabric/styling';
import defineProperty from '../../../../node_modules/@babel/runtime/helpers/defineProperty.js';
import '../../../../node_modules/core-js/modules/es.string.small.js';
import { sizeBoolean, presenceBoolean, personaPresenceSize } from '../PersonaConsts.js';

var GlobalClassNames = {
  presence: 'ms-Persona-presence',
  presenceIcon: 'ms-Persona-presenceIcon'
};
var getStyles = function getStyles(props) {
  var theme = props.theme;
  var semanticColors = theme.semanticColors,
      fonts = theme.fonts;
  var classNames = getGlobalClassNames(GlobalClassNames, theme);
  var size = sizeBoolean(props.size);
  var presence = presenceBoolean(props.presence); // Presence colors

  var presenceColorAvailable = '#6BB700';
  var presenceColorAway = '#FFAA44';
  var presenceColorBusy = '#C43148';
  var presenceColorDnd = '#C50F1F';
  var presenceColorOffline = '#8A8886';
  var presenceColorOof = '#B4009E';
  var isOpenCirclePresence = presence.isOffline || props.isOutOfOffice && (presence.isAvailable || presence.isBusy || presence.isAway || presence.isDoNotDisturb);
  var borderSizeForSmallPersonas = '1px';
  var borderSizeForLargePersonas = '2px';
  var borderSize = size.isSize72 || size.isSize100 ? borderSizeForLargePersonas : borderSizeForSmallPersonas;
  return {
    presence: [classNames.presence, {
      position: 'absolute',
      height: personaPresenceSize.size12,
      width: personaPresenceSize.size12,
      borderRadius: '50%',
      top: 'auto',
      right: '-2px',
      bottom: '-2px',
      border: "2px solid ".concat(semanticColors.bodyBackground),
      textAlign: 'center',
      boxSizing: 'content-box',
      backgroundClip: 'content-box',
      MsHighContrastAdjust: 'none',
      selectors: defineProperty({}, HighContrastSelector, {
        borderColor: 'Window',
        backgroundColor: 'WindowText'
      })
    }, (size.isSize8 || size.isSize10) && {
      right: 'auto',
      top: '7px',
      left: 0,
      border: 0,
      selectors: defineProperty({}, HighContrastSelector, {
        top: '9px',
        border: '1px solid WindowText'
      })
    }, (size.isSize8 || size.isSize10 || size.isSize24 || size.isSize28 || size.isSize32) && makeSizeStyle(personaPresenceSize.size8), (size.isSize40 || size.isSize48) && makeSizeStyle(personaPresenceSize.size12), size.isSize16 && {
      height: personaPresenceSize.size6,
      width: personaPresenceSize.size6,
      borderWidth: '1.5px'
    }, size.isSize56 && makeSizeStyle(personaPresenceSize.size16), size.isSize72 && makeSizeStyle(personaPresenceSize.size20), size.isSize100 && makeSizeStyle(personaPresenceSize.size28), size.isSize120 && makeSizeStyle(personaPresenceSize.size32), presence.isAvailable && {
      backgroundColor: presenceColorAvailable,
      selectors: defineProperty({}, HighContrastSelector, backgroundColor('Highlight'))
    }, presence.isAway && backgroundColor(presenceColorAway), presence.isBlocked && [{
      selectors: defineProperty({
        // Only show :after at larger sizes
        ':after': size.isSize40 || size.isSize48 || size.isSize72 || size.isSize100 ? {
          content: '""',
          width: '100%',
          height: borderSize,
          backgroundColor: presenceColorBusy,
          transform: 'translateY(-50%) rotate(-45deg)',
          position: 'absolute',
          top: '50%',
          left: 0
        } : undefined
      }, HighContrastSelector, {
        selectors: {
          ':after': {
            width: "calc(100% - 4px)",
            left: '2px',
            backgroundColor: 'Window'
          }
        }
      })
    }], presence.isBusy && backgroundColor(presenceColorBusy), presence.isDoNotDisturb && backgroundColor(presenceColorDnd), presence.isOffline && backgroundColor(presenceColorOffline), (isOpenCirclePresence || presence.isBlocked) && [{
      backgroundColor: semanticColors.bodyBackground,
      selectors: defineProperty({
        ':before': {
          content: '""',
          width: '100%',
          height: '100%',
          position: 'absolute',
          top: 0,
          left: 0,
          border: "".concat(borderSize, " solid ").concat(presenceColorBusy),
          borderRadius: '50%',
          boxSizing: 'border-box'
        }
      }, HighContrastSelector, {
        backgroundColor: 'WindowText',
        selectors: {
          ':before': {
            width: "calc(100% - 2px)",
            height: "calc(100% - 2px)",
            top: '1px',
            left: '1px',
            borderColor: 'Window'
          }
        }
      })
    }], isOpenCirclePresence && presence.isAvailable && makeBeforeBorderStyle(borderSize, presenceColorAvailable), isOpenCirclePresence && presence.isBusy && makeBeforeBorderStyle(borderSize, presenceColorBusy), isOpenCirclePresence && presence.isAway && makeBeforeBorderStyle(borderSize, presenceColorOof), isOpenCirclePresence && presence.isDoNotDisturb && makeBeforeBorderStyle(borderSize, presenceColorDnd), isOpenCirclePresence && presence.isOffline && makeBeforeBorderStyle(borderSize, presenceColorOffline), isOpenCirclePresence && presence.isOffline && props.isOutOfOffice && makeBeforeBorderStyle(borderSize, presenceColorOof)],
    presenceIcon: [classNames.presenceIcon, {
      color: semanticColors.bodyBackground,
      fontSize: '6px',
      lineHeight: personaPresenceSize.size12,
      verticalAlign: 'top',
      selectors: defineProperty({}, HighContrastSelector, {
        color: 'Window'
      })
    }, size.isSize56 && {
      fontSize: '8px',
      lineHeight: personaPresenceSize.size16
    }, size.isSize72 && {
      fontSize: fonts.small.fontSize,
      lineHeight: personaPresenceSize.size20
    }, size.isSize100 && {
      fontSize: fonts.medium.fontSize,
      lineHeight: personaPresenceSize.size28
    }, size.isSize120 && {
      fontSize: fonts.medium.fontSize,
      lineHeight: personaPresenceSize.size32
    }, presence.isAway && {
      position: 'relative',
      left: isOpenCirclePresence ? undefined : '1px'
    }, isOpenCirclePresence && presence.isAvailable && makeOpenCircleIconStyle(presenceColorAvailable), isOpenCirclePresence && presence.isBusy && makeOpenCircleIconStyle(presenceColorBusy), isOpenCirclePresence && presence.isAway && makeOpenCircleIconStyle(presenceColorOof), isOpenCirclePresence && presence.isDoNotDisturb && makeOpenCircleIconStyle(presenceColorDnd), isOpenCirclePresence && presence.isOffline && makeOpenCircleIconStyle(presenceColorOffline), isOpenCirclePresence && presence.isOffline && props.isOutOfOffice && makeOpenCircleIconStyle(presenceColorOof)]
  };
};

function makeOpenCircleIconStyle(color) {
  return {
    color: color,
    borderColor: color
  };
}

function makeBeforeBorderStyle(borderSize, color) {
  return {
    selectors: {
      ':before': {
        border: "".concat(borderSize, " solid ").concat(color)
      }
    }
  };
}

function makeSizeStyle(size) {
  return {
    height: size,
    width: size
  };
}

function backgroundColor(color) {
  return {
    backgroundColor: color
  };
}

export { getStyles };
